@@ -14,19 +14,6 @@
 		(When callsign or password is wrong, dv_echo was looped.)
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#include <arpa/inet.h>
-#include <linux/ipc.h>
-#include <linux/msg.h>
-#include <signal.h>
-#include <mqueue.h>
-#include <pthread.h>
-#include <errno.h>
 #include "dsgwd_pi.h"
 #include "node.h"
 
@@ -444,6 +431,8 @@ int main(int argc, const char **argv)
         udpAddr.sin_addr.s_addr = htonl(INADDR_ANY);
         bind(udpSocket, (struct sockaddr *)&udpAddr, sizeof(udpAddr));
 
+	loadCallCheckACL();
+
         FD_ZERO(&Mask);
         FD_SET(dstSocket, &Mask);
 	FD_SET(udpSocket, &Mask);
