@@ -3,6 +3,23 @@
 	Date		2014.01.20
 */
 
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netdb.h>
+#include <arpa/inet.h>
+#include <linux/ipc.h>
+#include <linux/msg.h>
+#include <signal.h>
+#include <mqueue.h>
+#include <pthread.h>
+#include <errno.h>
+
+
 #define FALSE           0
 #define TRUE            1
 #define MaxErrorBit     3
@@ -194,7 +211,7 @@ char		client_password[64];
 char		TrustDomainName[128];
 char		TrustDbDomainName[128];
 char		repeater_mode;
-
+char		CallCheck;
 struct	packet	dv_frame;
 
 unsigned	int	NodeVendorID;
